@@ -1,7 +1,7 @@
 import os
 import asyncio
 from metaapi_cloud_sdk import MetaApi
-from metaapi_cloud_sdk.clients.tradeException import TradeException
+from metaapi_cloud_sdk.clients.metaApi.tradeException import TradeException
 from datetime import datetime, timedelta
 
 # Note: for information on how to use this example code please read https://metaapi.cloud/docs/client/usingCodeExamples
@@ -10,12 +10,18 @@ token = os.getenv('TOKEN') or '<put in your token here>'
 accountId = os.getenv('ACCOUNT_ID') or '<put in your account id here>'
 api = MetaApi(token)
 
+
 async def test_meta_api_synchronization():
     try:
         account = await api.metatrader_account_api.get_account(accountId)
-        #  wait until account is deployed and connected to broker
-        print('Deploying account')
-        await account.deploy()
+        initial_state = account.state
+        deployed_states = ['DEPLOYING', 'DEPLOYED']
+
+        if initial_state not in deployed_states:
+            #  wait until account is deployed and connected to broker
+            print('Deploying account')
+            await account.deploy()
+
         print('Waiting for API server to connect to broker (may take couple of minutes)')
         await account.wait_connected()
 
@@ -51,10 +57,11 @@ async def test_meta_api_synchronization():
             print('Trade successful, result code is ' + result['stringCode'])
         except TradeException as err:
             print('Trade failed with result code ' + err.stringCode)
+        if initialState not in deployedStates:
+            # undeploy account if it was undeployed
+            print('Undeploying account')
+            await account.undeploy()
 
-        # finally, undeploy account after the test
-        print('Undeploying MT5 account so that it does not consume any unwanted resources')
-        await account.undeploy()
     except Exception as err:
         print(err)
 
