@@ -1,7 +1,7 @@
 import os
 import asyncio
 from metaapi_cloud_sdk import MetaApi
-from metaapi_cloud_sdk.clients.tradeException import TradeException
+from metaapi_cloud_sdk.clients.metaApi.tradeException import TradeException
 from datetime import datetime, timedelta
 
 # Note: for information on how to use this example code please read https://metaapi.cloud/docs/client/usingCodeExamples
@@ -27,7 +27,9 @@ async def test_meta_api_synchronization():
             print('Creating account profile')
             profile = await api.provisioning_profile_api.create_provisioning_profile({
                 'name': server_name,
-                'version': 4
+                'version': 4,
+                'brokerTimezone': 'EET',
+                'brokerDSTSwitchTimezone': 'EET'
             })
             await profile.upload_file('broker.srv', broker_srv_file)
         if profile and profile.status == 'new':
@@ -40,7 +42,7 @@ async def test_meta_api_synchronization():
         accounts = await api.metatrader_account_api.get_accounts()
         account = None
         for item in accounts:
-            if item.login == login and item.synchronization_mode == 'automatic' and item.type.startswith('cloud'):
+            if item.login == login and item.type.startswith('cloud'):
                 account = item
                 break
         if not account:
@@ -51,9 +53,7 @@ async def test_meta_api_synchronization():
                 'login': login,
                 'password': password,
                 'server': server_name,
-                'synchronizationMode': 'automatic',
                 'provisioningProfileId': profile.id,
-                'timeConverter': 'icmarkets',
                 'application': 'MetaApi',
                 'magic': 1000
             })
